
###################################################################################################
#  For "Hotelling Revisits the Lab: Equilibration in Continuous and Discrete Time" 
#  Journal of the Economic Science Association 
#  Curtis Kephart curtis.kephart@gmail.com
#  March 25 2015
#  
#  Data and analysis for figures and tables
#
###################################################################################################


# Packages & Setup ----
#useful data management packages
require(dplyr)
require(plyr)
require(reshape2)

#ploting packages and homemade functions
library(ggplot2)
library(scales)
require(grid)
library(gridExtra)
#Ensure this "Hotelling4PContTime_JESA" folder is your working director, getwd() setwd(dir = "...")
 source("Hotelling_GRAND_Metrics_Plot.R")

# packages for reg and HAC, cluster robust
library(sandwich)
library(lmtest)
library(car)



# Load Data ----
ticks_allHotelling <- read.csv("ticks_allHotelling.csv") # large, 175mb
# on periods, note that periods 1 and 2 were unpaid practice periods and removed
# robot indicates all-humam period-groups vs one-human-three-robot period groups
# strategy0 is position



# Figure 3, position rel freq histograms ----
# genearte individual plots for each treatment (needed to calc accurate relative frequencies)
# then place all three in same plot

#Setup
bindwidth.size = 0.02
axis.title.size = 19
axis.text.size = 15
ticks_allHotelling$Treatment <- mapvalues(ticks_allHotelling$treatment, from = c("CI", "CS", "D" ), to = c("Continuous Instant", "Continuous Slow", "Discrete"))


DS = ggplot(
  dplyr::filter(
    ticks_allHotelling, 
    treatment=="D" & period >= 9 & robot != "robots"
    ), 
  aes(x=strategy0, y=(..count..)/sum(..count..))) + 
  geom_bar(binwidth=0.03,colour="black", fill = "black") +
  scale_y_continuous(labels = percent) +
  geom_vline(xintercept = c(0.25,0.75),colour="#808080",linetype="longdash") +
  xlim(0,1) +
  labs(title="", x = "Positions", y = "Relative Frequency") +
  ggtitle("Discrete time") + 
  ylim(0,0.25) +
  theme_bw() +
  theme(axis.title = element_text(size = axis.title.size),
        axis.text = element_text(size = axis.text.size),
        plot.title = element_text(size = 20))


CI = ggplot(
  dplyr::filter(
    ticks_allHotelling, 
    treatment=="CI" & period >= 9 & robot != "robots"
  ), 
  aes(x=strategy0, y=(..count..)/sum(..count..))) + 
  geom_bar(binwidth=0.02,colour="black", fill = "black") +
  scale_y_continuous(labels = percent) +
  geom_vline(xintercept = c(0.25,0.75),colour="#808080",linetype="longdash") +
  xlim(0,1) +
  labs(title="", x = "Positions", y = "Relative Frequency") +
  ggtitle("Continuous time, instant") + 
  ylim(0,0.25) +
  theme_bw() +
  theme(axis.title = element_text(size = axis.title.size),
        axis.text = element_text(size = axis.text.size),
        plot.title = element_text(size = 20))

CS = ggplot(
  dplyr::filter(
    ticks_allHotelling, 
    treatment=="CS" & period >= 9 & robot != "robots"
  ), 
  aes(x=strategy0, y=(..count..)/sum(..count..))) + 
  geom_bar(binwidth=0.02,colour="black", fill = "black") +
  scale_y_continuous(labels = percent) +
  geom_vline(xintercept = c(0.25,0.75),colour="#808080",linetype="longdash") +
  xlim(0,1) +
  labs(title="", x = "Positions", y = "Relative Frequency") +
  ggtitle("Continuous time, slow") + 
  ylim(0,0.25) +
  theme_bw() +
  theme(axis.title = element_text(size = axis.title.size),
        axis.text = element_text(size = axis.text.size),
        plot.title = element_text(size = 20))



plot.figure3 = arrangeGrob(DS,CS,CI,
            nrow = 1)
plot.figure3
# Save Plot
# ggsave("HotellingLocReview_V3.pdf", plot.figure3,
#        width =12, height = 4, dpi = 200)

#Huck 2002 original data and simple figure ----
Huck2002 <- read.csv("~/Dropbox/Hotelling Model & Experiment/Hotelling RStudio Project/Hotelling/HuckMV2003.csv")
library(scales)
library(reshape2)
library(dplyr)

ticks_huck2002 <- rbind(
  data.frame(
    Player = 1,
    merge(
      melt(dplyr::select(Huck2002, SESSION, ROUND, POS_1),
           id = c("SESSION","ROUND"),
           value.name = "Location")[,c(1,2,4)],
      melt(dplyr::select(Huck2002, SESSION, ROUND, PROFIT_1),
           id = c("SESSION","ROUND"),
           value.name = "Payoff")[,c(1,2,4)],
      by = c("SESSION","ROUND"))
  ),
  data.frame(
    Player = 2,
    merge(
      melt(dplyr::select(Huck2002, SESSION, ROUND, POS_2),
           id = c("SESSION","ROUND"),
           value.name = "Location")[,c(1,2,4)],
      melt(dplyr::select(Huck2002, SESSION, ROUND, PROFIT_2),
           id = c("SESSION","ROUND"),
           value.name = "Payoff")[,c(1,2,4)],
      by = c("SESSION","ROUND"))
  ),
  data.frame(
    Player = 3,
    merge(
      melt(dplyr::select(Huck2002, SESSION, ROUND, POS_3),
           id = c("SESSION","ROUND"),
           value.name = "Location")[,c(1,2,4)],
      melt(dplyr::select(Huck2002, SESSION, ROUND, PROFIT_3),
           id = c("SESSION","ROUND"),
           value.name = "Payoff")[,c(1,2,4)],
      by = c("SESSION","ROUND"))
  ),
  data.frame(
    Player = 4,
    merge(
      melt(dplyr::select(Huck2002, SESSION, ROUND, POS_4),
           id = c("SESSION","ROUND"),
           value.name = "Location")[,c(1,2,4)],
      melt(dplyr::select(Huck2002, SESSION, ROUND, PROFIT_4),
           id = c("SESSION","ROUND"),
           value.name = "Payoff")[,c(1,2,4)],
      by = c("SESSION","ROUND"))
  )
)

ticks_huck2002 <- dplyr::arrange(ticks_huck2002, SESSION, ROUND, Player)
ggplot(ticks_huck2002, aes(x=Location,  y=(..count..)/sum(..count..))) + 
  geom_bar(binwidth=bindwidth.size*1000,colour="#808080") +
  scale_y_continuous(labels = percent) +
  geom_vline(xintercept = c(250,750),colour="#808080",linetype="longdash") +
  xlim(0,1000) +
  labs(title="", x = "Positions", y = "Relative Frequency") +
  ylim(0,0.25) +
  theme_bw() + 
  theme(axis.title = element_text(size = axis.title.size),
        axis.text = element_text(size = axis.text.size))

ggplot(dplyr::filter(ticks_huck2002, ROUND > 25 ), 
       aes(x=Location,  y=(..count..)/sum(..count..))) + 
  geom_bar(binwidth=bindwidth.size*1000,colour="#808080") +
  scale_y_continuous(labels = percent) +
  geom_vline(xintercept = c(250,750),colour="#808080",linetype="longdash") +
  xlim(0,1000) +
  labs(title="", x = "Positions", y = "Relative Frequency") +
  ylim(0,0.25) +
  theme_bw() + 
  theme(axis.title = element_text(size = axis.title.size),
        axis.text = element_text(size = axis.text.size))

# Generate "AvgDistData" data.frame from ticks_allHotelling ----
# takes my computer < 120 seconds
system.time({
  source("AvgDistMaker.R")
})

# Summary Stats ----
{
  
  # Average Distance from Eq - Not Including robot treatments
  AvgDistData %>%
    filter(name != "Overall") %>%
    group_by(treatment) %>%
    summarize(
      AvgScore = mean(AvgDistAbs),
      SDScore = sd(AvgDistAbs),
      N = length(AvgDistAbs)
      )
      
  # Overall Average Distance from Eq - Not Including robot treatments
  
  
  #  Avg Dist from Eq by Learning Level
  AvgDistData %>%
    filter(name != "Overall") %>%
    group_by(treatment,Learning_Sense_2) %>%
    summarize(
      AvgScore = mean(AvgDistAbs),
      SDScore = sd(AvgDistAbs),
      N = length(AvgDistAbs)
    )
  
  #formally table 3
  # Percent time within 1% of Pure NE - (% of time/subperiods AvgDistEq < 0.01)
  ddply(subset(AvgDistData,name!="Overall"),.(treatment,Learning_Sense_2),summarize,
        Percent_01 = round(length(AvgDistAbs[AvgDistAbs<00.0025]) / length(AvgDistAbs),4)*100,
        Percent_05 = round(length(AvgDistAbs[AvgDistAbs<0.0125]) / length(AvgDistAbs),4)*100,
        N = length(AvgDistAbs))
  
  #Overall
  ddply(subset(AvgDistData,name!="Overall"),.(treatment),summarize,
        Percent_01 = round(length(AvgDistAbs[AvgDistAbs<00.0025]) / length(AvgDistAbs),4)*100,
        Percent_05 = round(length(AvgDistAbs[AvgDistAbs<0.0125]) / length(AvgDistAbs),4)*100,
        N = length(AvgDistAbs))
  
  
  # Robust? - not as clear, but pretty good support for overall story
  # Percent time within 1% of Pure NE - (% of time/subperiods AvgDistEq < 0.01)
  ddply(subset(AvgDistData,name!="Overall"),.(treatment,Learning_Sense_1),summarize,
        Percent_01 = round(length(AvgDistAbs[AvgDistAbs<00.0025]) / length(AvgDistAbs),4)*100,
        Percent_05 = round(length(AvgDistAbs[AvgDistAbs<0.0125]) / length(AvgDistAbs),4)*100,
        N = length(AvgDistAbs))
  
}

# Figure 4 - AvgAbsDist by period and treatment ----
ggplot(data = AvgDistData %>% 
         dplyr::group_by(treatment,period) %>%
         dplyr::summarize(
           AvgDist = mean(AvgDistAbs)
         ), 
       aes(x=period, y=AvgDist, group = treatment)) + 
  geom_line(aes(colour = treatment, shape=treatment), size = 1) +
  geom_point(aes(colour = treatment, shape=treatment),size=4.5) +
  #ggtitle(paste("Average Distance from Equilibrium  (by treatment, by session, average of each full period)")) + 
  ylim(0,0.18) +
  theme_bw() + 
  xlab("              Period (12 periods each session)") + ylab("    Average Distance \n    from Pure Nash Equilibrium") + 
  theme(plot.title = element_text(lineheight=1, hjust = 0, face="bold", size =axis.text.size),
        legend.position= "top",
        legend.text = element_text(size=axis.text.size),
        legend.title = element_text(size = axis.text.size),
        axis.title  = element_text(hjust=0),
        axis.text = element_text(size=axis.text.size),
        axis.title.x = element_text(size=axis.text.size+1),
        axis.title.y = element_text(size=axis.text.size+2),
        plot.title = element_text(size = axis.text.size),
        legend.key = element_blank()) +
  geom_hline(yintercept = c(0.1715),colour="#808080",linetype="longdash") +
  scale_colour_manual(name="Treatment:    ",
                      breaks=c("Discrete","Continuous Slow","Continuous Instant"),
                      labels=c("Discrete       ","Continuous Slow      ","Continuous Instant"),
                      values=c("Blue","hotpink3", "DarkGreen")) +
  scale_shape_manual(name="Treatment:    ",
                     breaks=c("Discrete","Continuous Slow","Continuous Instant"),
                     labels=c("Discrete       ","Continuous Slow      ","Continuous Instant"),
                     values = c(15,19,17))
#for pdf 10in by 4.5in

# Figure 5 - AvgAbsDist by second, by treatment over the period----
ggplot(dplyr::filter(AvgDistData, name=="Overall"), aes(x=Time, y=AvgDistAbs, group=treatment)) +
  geom_line(aes(color = treatment, linetype = treatment), size = 1.2) +
  #   geom_line(aes(x=Time, y = 0.264*(1/Time) + 0.140*(Time-1)/Time),xend = 180, yend = .1,
  #             size = 1.5, alpha = 0.5, color = "Red") +
  #   geom_line(aes(x=Time, y = 0.264*(1/Time) + 0.0632*(Time-1)/Time),xend = 180, yend = .1,
  #             size = 1.5, alpha = 0.5, color = "Blue") +
  #   geom_line(aes(x=Time, y = 0.264*(1/Time) + 0.0478*(Time-1)/Time),xend = 180, yend = .1,
  #             size = 1.5, alpha = 0.5, color = "DarkGreen") +
  #ggtitle(paste("Average Distance from Equilibrium (on average by second, by treatment, over the period)")) + 
  xlab("               Time (seconds)") + ylab("     Average Distance \n    from Pure Nash Equilibrium") + 
  theme_bw() + 
  ylim(0,0.18) +
  xlim(0,180) +
  scale_x_continuous(breaks = seq(0,180,60)) +
  theme(plot.title = element_text(lineheight=1, hjust = 0, face="bold", size =axis.text.size),
        legend.position= "top",
        legend.text = element_text(size=axis.text.size),
        legend.title = element_text(size = axis.text.size),
        axis.title  = element_text(hjust=0),
        axis.text = element_text(size=axis.text.size),
        axis.title.x = element_text(size=axis.text.size+1),
        axis.title.y = element_text(size=axis.text.size+2),
        plot.title = element_text(size = axis.text.size),
        legend.key = element_blank())  +  
  geom_hline(yintercept = c(0.1715),colour="#808080",linetype="longdash") +
  scale_colour_manual(name="Treatment:    ",
                      breaks=c("Discrete","Continuous Slow","Continuous Instant"),
                      labels=c("Discrete       ","Continuous Slow      ","Continuous Instant"),
                      values=c("Blue","hotpink3", "DarkGreen")) +
  scale_linetype_manual(name="Treatment:    ",
                        breaks=c("Discrete","Continuous Slow","Continuous Instant"),
                        labels=c("Discrete       ","Continuous Slow      ","Continuous Instant"),
                        values = c("dashed","solid","twodash"))
#10 by 4.5


# Table 2  estiamtes of equaiton 4, Noussair Method, -----
##### Grpah with Noussair method
ggplot(AvgDistData[AvgDistData$name=="Overall",], aes(x=Time, y=AvgDistAbs,color=treatment)) +
  geom_line(size = 2, alpha = 0.1) +
  geom_line(aes(x=Time, y = 0.264*(1/Time) + 0.140*(Time-1)/Time),xend = 180, yend = .1,
            size = 1.5, alpha = 1, color = "Red") +
  geom_line(aes(x=Time, y = 0.264*(1/Time) + 0.0632*(Time-1)/Time),xend = 180, yend = .1,
            size = 1.5, alpha = 1, color = "Blue") +
  geom_line(aes(x=Time, y = 0.264*(1/Time) + 0.0478*(Time-1)/Time),xend = 180, yend = .1,
            size = 1.5, alpha = 1, color = "DarkGreen") +
  ggtitle(paste("Average Distance from Equilibrium   (on average by second, by treatment, over the period)")) + 
  xlab("               Time (seconds)") + ylab("     Average Distance \n    from Pure Nash Equilibrium") + 
  theme_bw() + 
  ylim(0,0.18) +
  xlim(0,180) +
  theme(plot.title = element_text(lineheight=1, hjust = 0, face="bold", size =19),
        legend.position= "top",
        legend.text = element_text(size=12),
        legend.title = element_text(size = 12),
        axis.title  = element_text(hjust=0),
        axis.text = element_text(size=axis.text.size),
        axis.title.x = element_text(size=axis.text.size+1),
        axis.title.y = element_text(size=axis.text.size+2)) +  
  geom_hline(yintercept = c(0.1715),colour="#808080",linetype="longdash") +
  scale_colour_manual(name="Treatment:    ",
                      breaks=c("Discrete","Continuous Slow","Continuous Instant"),
                      labels=c("Discrete       ","Continuous Slow      ","Continuous Instant"),
                      values=c("Red","DarkGreen", "Blue")) 


# Table coefficient estiamtes 
library(stargazer)
regNoussa <- lm(AvgDistAbs ~ 0 + I(1/Time) + treatment:I((Time-1)/Time), data=subset(AvgDistData.temp,name!="Overall" & Time >= 1))
summary(regNoussa) #note, not the right standard errors! correct estimates though
stargazer(regNoussa)

{
  #Test that beta_22 and beta_23 are stat different (result 3)
  AvgDistData.temp = AvgDistData
  AvgDistData.temp$CI = ifelse(AvgDistData.temp$treatment == "Continuous Instant", 0,1)
  AvgDistData.temp$CS = ifelse(AvgDistData.temp$treatment == "Continuous Slow", 0,1)
  AvgDistData.temp$DS = ifelse(AvgDistData.temp$treatment == "Discrete", 0,1)
  summary(
    lm(AvgDistAbs ~ 0 + I(1/Time) + I((CI-CS)*(Time-1)/Time) + I(DS*(Time-1)/Time) + I(CS*(Time-1)/Time), 
       data=subset(AvgDistData.temp,name!="Overall" & Time >= 1))
  )
}

{  
  # Cluster-robust standard errors ----
  # errors clustered at the group level 
  # see Cluster-robust standard errors using R by Mahmood Arai for details
  regNoussa = lm(AvgDistAbs ~ 0 + I(1/Time) + treatment:I((Time-1)/Time), 
                 data=subset(AvgDistData.temp,name!="Overall" & Time >= 1))
  summary(regNoussa)
  
  # Find silos
  AvgDistData.regNoussa = subset(AvgDistData.temp,name!="Overall" & Time >= 1)
  AvgDistData.regNoussa <- 
    dplyr::mutate(
      AvgDistData.regNoussa,
      silo = paste(substring(name, 1, 5),substring(name, nchar(as.character(name)), nchar(as.character(name))),sep = "")
    )
  table(AvgDistData.regNoussa$silo)
  
  library(sandwich)
  M <- length(unique(AvgDistData.regNoussa$silo))
  dfcw <- regNoussa$df / (regNoussa$df - (M -1))
  library(lmtest)
  coeftest(regNoussa, dfcw*vcov(regNoussa))
  
  clx <- function(fm, dfcw, cluster){
    library(sandwich)
    library(lmtest)
    M <- length(unique(cluster))
    N <- length(cluster)
    dfc <- (M/(M-1))*((N-1)/(N-fm$rank))
    u <- apply(estfun(fm),2,
               function(x) tapply(x, cluster, sum))
    vcovCL <- dfc*sandwich(fm, meat=crossprod(u)/N)*dfcw
    coeftest(fm, vcovCL) 
  }
  
  system.time({
    clx(regNoussa, dfcw, AvgDistData.regNoussa$silo)
  })
}


# HAC tests --------
# warning, the coeftest will take many minutes!
{
  coeftest(regNoussa, vcovHAC, weight = AvgDistData.regNoussa$silo)  
  
  # Test that CS and CI are staitically different with cluster robust standard errors #Test that beta_22 and beta_23 are stat different (result 3)
  regNoussa.HAC2 = lm(AvgDistAbs ~ 0 + I(1/Time) + I((CI-CS)*(Time-1)/Time) + I(DS*(Time-1)/Time) + I(CS*(Time-1)/Time), 
                      data=subset(AvgDistData.temp,name!="Overall" & Time >= 1))
  
  
  coeftest(regNoussa.HAC2, vcovHAC, weight = AvgDistData.regNoussa$silo)  
}


# Newey West for Panel Data Sets ----------------
# used STATA with http://www.kellogg.northwestern.edu/faculty/petersen/htm/papers/se/se_programming.htm
# alt mehtods above, all still give significant SEs
# tsset name2 Time  -- Time is( 180-Time, cluster around name (group). 
# newey AvgDistAbs x1 + treatment2:x2, lag(1) force noconstant # STATA
# Unfortunately, I could not find a good newey west for panel implementation in R


# Redoing Table 2 "Estimates of Equation ..." ----


# How performance against robots relates to AvgAbsDist ----
{
  load("AvgDist_bySubject.RData")
  
  AvgDist.robo.sum <-dplyr::summarize(
    dplyr::group_by(
      dplyr::filter(AvgDistData.temp, name != "Overall" & Time > 30), treatment, name),
    MeanAvgDist = mean(AvgDistAbs),
    MedAvgDist  = median(AvgDistAbs),
    MinAvgDist  = min(AvgDistAbs),
    MaxAvgDist  = max(AvgDistAbs),
    period = unique(period)
  )
  
  AvgDist.robo.sum <- dplyr::mutate(
    AvgDist.robo.sum, 
    period = period - 2,
    treatment2 = substr(x = as.character(name), 4,5),
    treatment2 = ifelse(treatment2 == "D-", "DS", treatment2),
    silo = substr(name, nchar(as.character(name)), nchar(as.character(name)))
  )
  
  
  AvgDist_bySubject <- dplyr::mutate(
    AvgDist_bySubject, 
    Robo = (Robo1 + Robo2 + Robo3 + Robo4) / 4
  )
  
  AvgDist_bySubject <- dplyr::mutate(
    dplyr::group_by(AvgDist_bySubject, treatment), 
    Robo.SD = (Robo - mean(Robo)) / sd(Robo)
  )
  
  library(reshape)
  library(reshape2)
  AvgDist_bySubject <- cast(AvgDist_bySubject,
                            treatment + silo + Period ~ subject, value = c("Robo.SD"), mean)
  names(AvgDist_bySubject)[4:15] = paste("s",1:12, sep = "")
  AvgDist_bySubject[4:15][is.na(AvgDist_bySubject[4:15])] = 0
  AvgDist_bySubject <- dplyr::mutate(
    AvgDist_bySubject, 
    AvgRoboScore = (s1+s2+s3+s4+s5+s6+s7+s8+s9+s10+s11+s12) / 4
  )
  
  AvgDist_bySubject <- dplyr::select(AvgDist_bySubject, treatment, silo, Period, AvgRoboScore)
  names(AvgDist_bySubject) = c("treatment2", "silo", "period", "AvgRoboScore")
  
  AvgDist.robo.sum <- merge(AvgDist.robo.sum, AvgDist_bySubject, 
                            by = c("treatment2","silo","period"))
  
  ggplot(AvgDist.robo.sum, 
         aes(x = AvgRoboScore, y = MeanAvgDist, group = treatment)) + 
    geom_point(aes(colour = treatment)) + 
    geom_smooth(aes(colour = treatment), method = "lm", fill = NA) + 
    theme_bw()
  
  summary(lm(MeanAvgDist ~ treatment + treatment:AvgRoboScore, data = AvgDist.robo.sum))
  
  summary(AvgDist.robo.sum)
  
}

# errors clustered at the group level 
{
  AvgDistData.robo <- AvgDistData.temp
  AvgDistData.robo <- (dplyr::mutate(
    AvgDistData.robo, 
    silo = substr(as.character(name), nchar(as.character(name)), nchar(as.character(name))),
    period = period - 2
  ))
  
  # AvgDistData.robo <- merge(
  #   AvgDistData.robo, 
  #   data.frame(treatment = c("Discrete","Continuous Slow","Continuous Instant"), 
  #              treatment2 = c("DS","CS","CI")),
  #   by = "treatment")
  
  AvgDistData.robo <- dplyr::left_join(
    AvgDistData.robo, 
    dplyr::select(AvgDist.robo.sum, treatment, silo, period,AvgRoboScore),
    by = c("treatment","silo","period")
  )
  
  regNoussa.Robo = lm(AvgDistAbs ~ 0 + I(1/Time) + treatment:I((Time-1)/Time) + AvgRoboScore, 
                      data=subset(AvgDistData.robo,name!="Overall" & Time >= 1))
  
  # table 2, panel 2
  #again, for standard errors refer to STATA, newey west for panel
  # steps here: http://www.kellogg.northwestern.edu/faculty/petersen/htm/papers/se/se_programming.htm
  summary(regNoussa.Robo)
  
  
  
  
#   # Find silos
#   AvgDistData.regNoussa.robo = subset(AvgDistData.robo,name!="Overall" & Time >= 1)
#   AvgDistData.regNoussa.robo <- 
#     dplyr::mutate(
#       AvgDistData.regNoussa.robo,
#       silo = paste(substring(name, 1, 5),substring(name, nchar(as.character(name)), nchar(as.character(name))),sep = "")
#     )
#   table(AvgDistData.regNoussa.robo$silo)
#   
#   library(sandwich)
#   M <- length(unique(AvgDistData.regNoussa.robo$silo))
#   dfcw <- regNoussa$df / (regNoussa$df - (M -1))
#   library(lmtest)
#   coeftest(regNoussa.Robo, dfcw*vcov(regNoussa.Robo))
#   
#   system.time({
#     clx(regNoussa.Robo, dfcw, AvgDistData.regNoussa.robo$silo)
#     coeftest(regNoussa.Robo, vcovHAC, weight = AvgDistData.regNoussa.robo$silo)
#   })
}

# Table 2 Panel 3, Effect of Robots on avgabsdist, by treatment----
{
  
  
  regNoussa.Robo.trt = lm(AvgDistAbs ~ 0 + I(1/Time) + treatment:I((Time-1)/Time) + treatment:AvgRoboScore, 
                          data=subset(AvgDistData.robo,name!="Overall" & Time >= 1))
 
  
  
  #again, for standard errors refer to STATA, newey west for panel
  # steps here: http://www.kellogg.northwestern.edu/faculty/petersen/htm/papers/se/se_programming.htm
  summary(regNoussa.Robo.trt)
  
#   # Find silos
#   AvgDistData.regNoussa.robo = subset(AvgDistData.robo,name!="Overall" & Time >= 1)
#   AvgDistData.regNoussa.robo <- 
#     dplyr::mutate(
#       AvgDistData.regNoussa.robo,
#       silo = paste(substring(name, 1, 5),substring(name, nchar(as.character(name)), nchar(as.character(name))),sep = "")
#     )
#   table(AvgDistData.regNoussa.robo$silo)
#   
#   library(sandwich)
#   M <- length(unique(AvgDistData.regNoussa.robo$silo))
#   dfcw <- regNoussa$df / (regNoussa$df - (M -1))
#   library(lmtest)
#   coeftest(regNoussa.Robo.trt, dfcw*vcov(regNoussa.Robo.trt))
#   
#   
#   system.time({
#     clx(regNoussa.Robo.trt, dfcw, AvgDistData.regNoussa.robo$silo)
#     coeftest(regNoussa.Robo.trt, vcovHAC, weight = AvgDistData.regNoussa.robo$silo)
#   })
}

# Robo Scores VS overall scores ----
{
  load("HL_Test_Results_plyrScores.RData") #HL_Test_Results
  
  HL_Test_Results <- dplyr::mutate(
    HL_Test_Results, 
    RoboAvg = (Robo1 + Robo2 + Robo3 + Robo4) / 4,
    HumanAvg = (payoff - (4*RoboAvg)) / 8
  )
  
  cor(HL_Test_Results$RoboAvg,
      HL_Test_Results$HumanAvg)
  
  ggplot(HL_Test_Results,
         aes(x = RoboAvg, y = HumanAvg, group = treatment)) + 
    geom_point(aes(colour = treatment), size = 4)  +
    theme_bw() +
    geom_smooth(aes(colour = treatment),method = "lm", se = F)
  
  
}






# Figure 6 Observatiosn of average absolute distance ----
## hist/pdf of Avg Dist by treatments
ggplot(AvgDistData[AvgDistData$name!="Overall",], aes(AvgDistAbs)) +
  geom_histogram(aes(y=..density..),binwidth=0.01) +
  facet_grid(~ treatment) + 
  theme_bw() + 
  theme(
    strip.text = element_text(size = 19),
    strip.background = element_rect(fill = "white", color = "white"),
    axis.title = element_text(size = 18),
    axis.text = element_text(size = 16, color = "grey12"),
    title = element_text()
  ) + 
  xlab("Observations of Average Absolute Distance") + ylab("Density") #+
#geom_vline(xintercept = 0,colour="DarkRed", linetype = "longdash")
# plot pdf, 9in by 4in, looks good

# formally figure 6, emprical CDF of AvgAbsDist by treatment
ggplot(AvgDistData[AvgDistData$name!="Overall",], aes(AvgDistAbs, colour = treatment)) + 
  stat_ecdf(size=1) +
  xlim(min(AvgDistData$AvgDistAbs),max(AvgDistData$AvgDistAbs)) + 
  theme_bw() + 
  ggtitle("CDF of Average Absolute Distances") + 
  theme(plot.title = element_text(size = 18),
        strip.background = element_rect(fill = "white", color = "white"),
        axis.title = element_text(size = 15),
        axis.text = element_text(size = 14, color = "grey12"),
        legend.key = element_blank(),
        legend.text = element_text(size=12),
        legend.title = element_text(size = 12)) + 
  xlab("Average Absolute Distance") + ylab("Cumulative Density") +
  guides(colour = guide_legend(override.aes = list(size=6))) +
  scale_colour_manual(name="Treatment:    ",
                      breaks=c("Discrete","Continuous Slow","Continuous Instant"),
                      labels=c("Discrete       ","Continuous Slow      ","Continuous Instant"),
                      values=c("Red","DarkGreen", "Blue")) 
# 9 by 6

