

require(dplyr)
require(ggplot2)
require(plyr)
require(grid)


# this script assumes that we've loaded our data. ticks_allHotelling

# Create "AllNames" - List of all-Human Periods ----
# AllNames is a simple summary of the naming index of all session periods that don't involve robots
{
  AllNames <- ticks_allHotelling[!duplicated(paste(ticks_allHotelling$session,ticks_allHotelling$name)),]
  AllNames <- dplyr::filter(
    AllNames, 
    robot == "humans")
  AllNames <- dplyr::select(
    AllNames,
    name, session, treatment
  )
  
  substrRight <- function(x, n){
    substr(x, nchar(x)-n+1, nchar(x))
  }
  
  AllNames <- dplyr::mutate(
    AllNames, 
    session = ifelse(treatment == "D",
                     yes = paste(session,"S",sep=""),
                     no = as.character(session)),
    treatment = ifelse(treatment == "D", 
                       yes = "Discrete",
                       no = ifelse(treatment == "CI",
                                   yes = "Continuous Instant",
                                   no = "Continuous Slow")),
    Silo = substrRight(as.character(name),1)
    
  )
  
}

# Create AvgDist Dataset for Discrete time treatments ----
# done because discrete data is at the subperiod level
{
  #    takes about 
  AvgDistDS <- data.frame(name="",Time=0,AvgDistAbs=0,AvgDist=0,treatment="Discrete")
  AvgDistDS <- AvgDistDS[-1,]
  TreatmentSubset <- subset(AllNames,treatment=="Discrete")
  PeriodsNames <- unique(TreatmentSubset$name)
  
  for (NAME in PeriodsNames){
    Temp <- subset(ticks_allHotelling,name==NAME)
    Temp$CountOrd <- rep(1:4, nrow(Temp)/4)
    Temp$ActinOrd <- unlist (with( Temp, tapply(strategy0,Temp$subperiod, sort)) )
    
    TIME <- unique(Temp$subperiod)
    
    ord1 <- subset(Temp, CountOrd==1)
    ord2 <- subset(Temp, CountOrd==2)
    ord3 <- subset(Temp, CountOrd==3)
    ord4 <- subset(Temp, CountOrd==4)             
    ABS <- I( ( abs(ord1$ActinOrd-0.25)+abs(ord2$ActinOrd-0.25)+abs(ord3$ActinOrd-0.75)+abs(ord4$ActinOrd-0.75) ) / 4 )
    AvgDist <- I( ( (ord1$ActinOrd-0.25)+(ord2$ActinOrd-0.25)+(ord3$ActinOrd-0.75)+(ord4$ActinOrd-0.75) ) / 4 )
    
    NewDataFrame <- data.frame(name=rep(NAME,length(ABS)),
                               Time=TIME,
                               AvgDistAbs=ABS,
                               AvgDist=AvgDist,
                               treatment="Discrete")
    
    AvgDistDS <- rbind(AvgDistDS,NewDataFrame)
    
  }
  
  
  HistwNormDist <- function(X,breaks=50,xlim=range(breaks)){
    #A function that produces a hist iwth normal dist
    h<-hist(X,breaks,xlim=xlim,main=deparse(substitute(X)),xlab=deparse(substitute(X)))
    xfit<-seq(min(X),max(X),length=40) 
    yfit<-dnorm(xfit,mean=mean(X),sd=sd(X)) 
    yfit <- yfit*diff(h$mids[1:2])*length(X) 
    lines(xfit, yfit, col="grey", lwd=2)
  }
  
  # Average Average Distance
  for (i in unique(AvgDistDS$Time)){
    temp <- subset(AvgDistDS, Time==i)
    ABS <- mean(temp$AvgDistAbs)
    AvgDist <- mean(temp$AvgDist)
    
    NewDataFrame <- data.frame(name="Overall",
                               Time=i,
                               AvgDistAbs=ABS,
                               AvgDist=AvgDist,
                               treatment="Discrete")
    AvgDistDS <- rbind(AvgDistDS,NewDataFrame)
  }
  
}

# Create AvgDist Dataset for Continuous Instant time treatments ----
{
  AvgDistCI <- data.frame(name="",Time=0,AvgDistAbs=0,AvgDist=0,treatment="Continuous Slow")
  AvgDistCI <- AvgDistCI[-1,]
  TreatmentSubset <- subset(AllNames,treatment=="Continuous Instant")
  PeriodsNames <- unique(TreatmentSubset$name)
  
  for (NAME in PeriodsNames){
    Temp <- subset(ticks_allHotelling,name==NAME)
    Temp$CountOrd <- rep(1:4, nrow(Temp)/4)
    Temp$ActinOrd <- unlist (with( Temp, tapply(strategy0,I(max(Temp$secondsLeft)-secondsLeft), sort)) )
    
    TIME <- unique(Temp$secondsLeft)
    TIME <- I(max(TIME)-TIME)
    
    ord1 <- subset(Temp, CountOrd==1)
    ord2 <- subset(Temp, CountOrd==2)
    ord3 <- subset(Temp, CountOrd==3)
    ord4 <- subset(Temp, CountOrd==4)             
    ABS <- I( ( abs(ord1$ActinOrd-0.25)+abs(ord2$ActinOrd-0.25)+abs(ord3$ActinOrd-0.75)+abs(ord4$ActinOrd-0.75) ) / 4 )
    AvgDist <- I( ( (ord1$ActinOrd-0.25)+(ord2$ActinOrd-0.25)+(ord3$ActinOrd-0.75)+(ord4$ActinOrd-0.75) ) / 4 )
    
    NewDataFrame <- data.frame(name=rep(NAME,length(ABS)),
                               Time=TIME,
                               AvgDistAbs=ABS,
                               AvgDist=AvgDist,
                               treatment="Continuous Instant")
    
    AvgDistCI <- rbind(AvgDistCI,NewDataFrame)
    
  }
  
  # Average Average Continuous Instant 
  for (i in seq(0.5,179.5,1)){
    temp <- subset(AvgDistCI, Time>i-0.5 & Time<i+0.5)
    ABS <- mean(temp$AvgDistAbs)
    AvgDist <- mean(temp$AvgDist)
    
    NewDataFrame <- data.frame(name="Overall",
                               Time=i,
                               AvgDistAbs=ABS,
                               AvgDist=AvgDist,
                               treatment="Continuous Instant")
    AvgDistCI <- rbind(AvgDistCI,NewDataFrame)
  }
  
}

# Create AvgDist Dataset for Continuous SLow time treatments ----
system.time({
  AvgDistCS <- data.frame(name="",Time=0,AvgDistAbs=0,AvgDist=0,treatment="Continuous Slow")
  AvgDistCS <- AvgDistCS[-1,]
  TreatmentSubset <- subset(AllNames,treatment=="Continuous Slow")
  PeriodsNames <- unique(TreatmentSubset$name)
  
  for (NAME in PeriodsNames){
    Temp <- subset(ticks_allHotelling,name==NAME)
    Temp$CountOrd <- rep(1:4, nrow(Temp)/4)
    Temp$ActinOrd <- unlist (with( Temp, tapply(strategy0,I(max(Temp$secondsLeft)-secondsLeft), sort)) )
    
    TIME <- unique(Temp$secondsLeft)
    TIME <- I(max(TIME)-TIME)
    
    ord1 <- subset(Temp, CountOrd==1)
    ord2 <- subset(Temp, CountOrd==2)
    ord3 <- subset(Temp, CountOrd==3)
    ord4 <- subset(Temp, CountOrd==4)             
    ABS <- I( ( abs(ord1$ActinOrd-0.25)+abs(ord2$ActinOrd-0.25)+abs(ord3$ActinOrd-0.75)+abs(ord4$ActinOrd-0.75) ) / 4 )
    AvgDist <- I( ( (ord1$ActinOrd-0.25)+(ord2$ActinOrd-0.25)+(ord3$ActinOrd-0.75)+(ord4$ActinOrd-0.75) ) / 4 )
    
    NewDataFrame <- data.frame(name=rep(NAME,length(ABS)),
                               Time=TIME,
                               AvgDistAbs=ABS,
                               AvgDist=AvgDist,
                               treatment="Continuous Slow")
    
    AvgDistCS <- rbind(AvgDistCS,NewDataFrame)
    
  }
  
  # Average Average Continuous SLow 
  for (i in seq(0.5,179.5,1)){
    temp <- subset(AvgDistCS, Time>i-0.5 & Time<i+0.5)
    ABS <- mean(temp$AvgDistAbs)
    AvgDist <- mean(temp$AvgDist)
    
    NewDataFrame <- data.frame(name="Overall",
                               Time=i,
                               AvgDistAbs=ABS,
                               AvgDist=AvgDist,
                               treatment="Continuous Slow")
    AvgDistCS <- rbind(AvgDistCS,NewDataFrame)
  }
  
})

#Clean and create AvgAbsData dataframe ----
system.time({
  rm(ord1,ord2,ord3,ord4,Temp, temp, NewDataFrame)
  
  
  ## plot Continuous slow ----
  ggplot(AvgDistCS, aes(x=Time, y=AvgDistAbs, group=name)) +
    geom_line(colour="grey60") +
    geom_line(data=AvgDistCS[AvgDistCS$name=="Overall",], size=2) +
    ylim(0,0.4)
  
  ## For discrete time treatment, convert periods into seconds. ----
  AvgDistDS$Time <- 3*AvgDistDS$Time
  
  
  ## Appears to be issue with AvgDist metric at time==180 for all continuous time treatments
  # this issue appears to be the result of ticks secondsLeft==180 repeat twice, so I'll delete and time > 179.9
  AvgDistCI <- subset(AvgDistCI,Time <= 179.9)
  AvgDistCS <- subset(AvgDistCS,Time <= 179.9)
  
  ## Combine all AvgDistData ----
  AvgDistData <- rbind(AvgDistDS, AvgDistCI, AvgDistCS)
  
  
  #Summary stats on AvgDist fronm Eq by treatment and by learning level
  ticks_allHotelling.temp <- subset(ticks_allHotelling,,c("period","name","Learning_Sense_1","Learning_Sense_2"))
  ticks_allHotelling.temp <- ticks_allHotelling.temp[!duplicated(ticks_allHotelling.temp$name),]
  
  AvgDistData <- merge(AvgDistData, 
                       ticks_allHotelling.temp, 
                       by.x = c("name"), 
                       by.y = c("name"),
                       all.x=TRUE) 
  
})







